/* A Bison parser, made by GNU Bison 3.3.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Undocumented macros, especially those whose name start with YY_,
   are private implementation details.  Do not rely on them.  */

#ifndef YY_YY_Y_TAB_H_INCLUDED
# define YY_YY_Y_TAB_H_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int yydebug;
#endif

/* Token type.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    K_ADD = 258,
    K_ADMIN = 259,
    K_ALL = 260,
    K_BACKUP = 261,
    K_CLIENT = 262,
    K_CLONE = 263,
    K_CLUSTER = 264,
    K_CLUSTERNAME = 265,
    K_COMMENT = 266,
    K_CONFIG = 267,
    K_CONFIRMED = 268,
    K_CONNINFO = 269,
    K_CONNRETRY = 270,
    K_COPY = 271,
    K_CREATE = 272,
    K_DATE = 273,
    K_DFORMAT = 274,
    K_DROP = 275,
    K_ECHO = 276,
    K_ERROR = 277,
    K_EVENT = 278,
    K_EXECUTE = 279,
    K_EXIT = 280,
    K_FAILOVER = 281,
    K_FALSE = 282,
    K_FILENAME = 283,
    K_FINISH = 284,
    K_FOR = 285,
    K_FORWARD = 286,
    K_FULL = 287,
    K_FUNCTIONS = 288,
    K_ID = 289,
    K_INIT = 290,
    K_KEY = 291,
    K_LISTEN = 292,
    K_LOCK = 293,
    K_LOG = 294,
    K_MERGE = 295,
    K_MOVE = 296,
    K_NAME = 297,
    K_NEW = 298,
    K_NO = 299,
    K_NODE = 300,
    K_OFF = 301,
    K_OLD = 302,
    K_ON = 303,
    K_ONLY = 304,
    K_ORIGIN = 305,
    K_PATH = 306,
    K_PREPARE = 307,
    K_PROVIDER = 308,
    K_QUALIFIED = 309,
    K_RECEIVER = 310,
    K_RESTART = 311,
    K_SCRIPT = 312,
    K_SEQUENCE = 313,
    K_SERVER = 314,
    K_SET = 315,
    K_SLEEP = 316,
    K_SQL = 317,
    K_STORE = 318,
    K_SUBSCRIBE = 319,
    K_SUCCESS = 320,
    K_SWITCH = 321,
    K_SYNC = 322,
    K_TABLE = 323,
    K_TIMEOUT = 324,
    K_TRUE = 325,
    K_TRY = 326,
    K_UNINSTALL = 327,
    K_UNLOCK = 328,
    K_UNSUBSCRIBE = 329,
    K_UPDATE = 330,
    K_WAIT = 331,
    K_YES = 332,
    K_OMIT = 333,
    K_REPAIR = 334,
    K_RESUBSCRIBE = 335,
    K_SECONDS = 336,
    K_SEQUENCES = 337,
    K_TABLES = 338,
    T_IDENT = 339,
    T_LITERAL = 340,
    T_NUMBER = 341
  };
#endif
/* Tokens.  */
#define K_ADD 258
#define K_ADMIN 259
#define K_ALL 260
#define K_BACKUP 261
#define K_CLIENT 262
#define K_CLONE 263
#define K_CLUSTER 264
#define K_CLUSTERNAME 265
#define K_COMMENT 266
#define K_CONFIG 267
#define K_CONFIRMED 268
#define K_CONNINFO 269
#define K_CONNRETRY 270
#define K_COPY 271
#define K_CREATE 272
#define K_DATE 273
#define K_DFORMAT 274
#define K_DROP 275
#define K_ECHO 276
#define K_ERROR 277
#define K_EVENT 278
#define K_EXECUTE 279
#define K_EXIT 280
#define K_FAILOVER 281
#define K_FALSE 282
#define K_FILENAME 283
#define K_FINISH 284
#define K_FOR 285
#define K_FORWARD 286
#define K_FULL 287
#define K_FUNCTIONS 288
#define K_ID 289
#define K_INIT 290
#define K_KEY 291
#define K_LISTEN 292
#define K_LOCK 293
#define K_LOG 294
#define K_MERGE 295
#define K_MOVE 296
#define K_NAME 297
#define K_NEW 298
#define K_NO 299
#define K_NODE 300
#define K_OFF 301
#define K_OLD 302
#define K_ON 303
#define K_ONLY 304
#define K_ORIGIN 305
#define K_PATH 306
#define K_PREPARE 307
#define K_PROVIDER 308
#define K_QUALIFIED 309
#define K_RECEIVER 310
#define K_RESTART 311
#define K_SCRIPT 312
#define K_SEQUENCE 313
#define K_SERVER 314
#define K_SET 315
#define K_SLEEP 316
#define K_SQL 317
#define K_STORE 318
#define K_SUBSCRIBE 319
#define K_SUCCESS 320
#define K_SWITCH 321
#define K_SYNC 322
#define K_TABLE 323
#define K_TIMEOUT 324
#define K_TRUE 325
#define K_TRY 326
#define K_UNINSTALL 327
#define K_UNLOCK 328
#define K_UNSUBSCRIBE 329
#define K_UPDATE 330
#define K_WAIT 331
#define K_YES 332
#define K_OMIT 333
#define K_REPAIR 334
#define K_RESUBSCRIBE 335
#define K_SECONDS 336
#define K_SEQUENCES 337
#define K_TABLES 338
#define T_IDENT 339
#define T_LITERAL 340
#define T_NUMBER 341

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED

union YYSTYPE
{
#line 54 "parser.y" /* yacc.c:1921  */

	int32		ival;
	char		*str;
	option_list	*opt_list;
	SlonikAdmInfo	*adm_info;
	SlonikStmt	*statement;
	failed_node_entry * failed_node_entry;

#line 239 "y.tab.h" /* yacc.c:1921  */
};

typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif


extern YYSTYPE yylval;

int yyparse (void);

#endif /* !YY_YY_Y_TAB_H_INCLUDED  */
